==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionFluentImpl<A extends SubscriptionFluent<A>> extends BaseFluent<A> implements SubscriptionFluent<A>{
  public SubscriptionFluentImpl() {
  }
  public SubscriptionFluentImpl(Subscription instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SubscriptionSpecBuilder spec;
  private SubscriptionStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SubscriptionFluent.MetadataNested<A> withNewMetadata() {
    return new SubscriptionFluentImpl.MetadataNestedImpl();
  }
  public SubscriptionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SubscriptionFluentImpl.MetadataNestedImpl(item);
  }
  public SubscriptionFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SubscriptionFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SubscriptionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubscriptionSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SubscriptionSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SubscriptionSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SubscriptionSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public SubscriptionFluent.SpecNested<A> withNewSpec() {
    return new SubscriptionFluentImpl.SpecNestedImpl();
  }
  public SubscriptionFluent.SpecNested<A> withNewSpecLike(SubscriptionSpec item) {
    return new SubscriptionFluentImpl.SpecNestedImpl(item);
  }
  public SubscriptionFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SubscriptionFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SubscriptionSpecBuilder().build());
  }
  public SubscriptionFluent.SpecNested<A> editOrNewSpecLike(SubscriptionSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubscriptionStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SubscriptionStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SubscriptionStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SubscriptionStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public SubscriptionFluent.StatusNested<A> withNewStatus() {
    return new SubscriptionFluentImpl.StatusNestedImpl();
  }
  public SubscriptionFluent.StatusNested<A> withNewStatusLike(SubscriptionStatus item) {
    return new SubscriptionFluentImpl.StatusNestedImpl(item);
  }
  public SubscriptionFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SubscriptionFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SubscriptionStatusBuilder().build());
  }
  public SubscriptionFluent.StatusNested<A> editOrNewStatusLike(SubscriptionStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubscriptionFluentImpl that = (SubscriptionFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SubscriptionFluent.MetadataNested<N>> implements SubscriptionFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SubscriptionFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SubscriptionSpecFluentImpl<SubscriptionFluent.SpecNested<N>> implements SubscriptionFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SubscriptionSpec item) {
      this.builder = new SubscriptionSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SubscriptionSpecBuilder(this);
    }
    SubscriptionSpecBuilder builder;
    public N and() {
      return (N) SubscriptionFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SubscriptionStatusFluentImpl<SubscriptionFluent.StatusNested<N>> implements SubscriptionFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SubscriptionStatus item) {
      this.builder = new SubscriptionStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SubscriptionStatusBuilder(this);
    }
    SubscriptionStatusBuilder builder;
    public N and() {
      return (N) SubscriptionFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionFluentImpl<A extends SubscriptionFluent<A>> extends BaseFluent<A> implements SubscriptionFluent<A>{
  public SubscriptionFluentImpl() {
  }
  public SubscriptionFluentImpl(Subscription instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SubscriptionSpecBuilder spec;
  private SubscriptionStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SubscriptionFluentImpl.MetadataNested<A> withNewMetadata() {
    return new SubscriptionFluentImpl.MetadataNestedImpl();
  }
  public SubscriptionFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SubscriptionFluentImpl.MetadataNestedImpl(item);
  }
  public SubscriptionFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SubscriptionFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SubscriptionFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubscriptionSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SubscriptionSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SubscriptionSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SubscriptionSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public SubscriptionFluentImpl.SpecNested<A> withNewSpec() {
    return new SubscriptionFluentImpl.SpecNestedImpl();
  }
  public SubscriptionFluentImpl.SpecNested<A> withNewSpecLike(SubscriptionSpec item) {
    return new SubscriptionFluentImpl.SpecNestedImpl(item);
  }
  public SubscriptionFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SubscriptionFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SubscriptionSpecBuilder().build());
  }
  public SubscriptionFluentImpl.SpecNested<A> editOrNewSpecLike(SubscriptionSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubscriptionStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SubscriptionStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SubscriptionStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SubscriptionStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public SubscriptionFluentImpl.StatusNested<A> withNewStatus() {
    return new SubscriptionFluentImpl.StatusNestedImpl();
  }
  public SubscriptionFluentImpl.StatusNested<A> withNewStatusLike(SubscriptionStatus item) {
    return new SubscriptionFluentImpl.StatusNestedImpl(item);
  }
  public SubscriptionFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SubscriptionFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SubscriptionStatusBuilder().build());
  }
  public SubscriptionFluentImpl.StatusNested<A> editOrNewStatusLike(SubscriptionStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionFluentImpl that = (SubscriptionFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SubscriptionFluentImpl.MetadataNested<N>> implements SubscriptionFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SubscriptionFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SubscriptionSpecFluentImpl<SubscriptionFluentImpl.SpecNested<N>> implements SubscriptionFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SubscriptionSpec item) {
      this.builder = new SubscriptionSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SubscriptionSpecBuilder(this);
    }
    SubscriptionSpecBuilder builder;
    public N and() {
      return (N) SubscriptionFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SubscriptionStatusFluentImpl<SubscriptionFluentImpl.StatusNested<N>> implements SubscriptionFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SubscriptionStatus item) {
      this.builder = new SubscriptionStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SubscriptionStatusBuilder(this);
    }
    SubscriptionStatusBuilder builder;
    public N and() {
      return (N) SubscriptionFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
